pub enum CfgFeature<'a> {
Single(UniqueIdent<'a>),
AnyOf(BTreeSet<UniqueIdent<'a>>),
AllOf(BTreeSet<UniqueIdent<'a>>),
OwnAndUsedBy {
own: UniqueIdent<'a>,
used_by: BTreeSet<UniqueIdent<'a>>,
},
}Expand description
Generates a #[cfg(...)] attribute for conditional compilation.
Variants
Single(UniqueIdent<'a>)
A single feature = "name" predicate.
AnyOf(BTreeSet<UniqueIdent<'a>>)
A compound any(feature = "a", feature = "b", ...) predicate.
AllOf(BTreeSet<UniqueIdent<'a>>)
A compound all(feature = "a", feature = "b", ...) predicate.
OwnAndUsedBy
A compound all(feature = "own", any(feature = "a", ...)) predicate,
used for schema types that both specify an x-resourceId, and are
used by operations that specify an x-resource-name.
Implementations
Sourceimpl<'a> CfgFeature<'a>
impl<'a> CfgFeature<'a>
Sourcepub fn for_schema_type(
graph: &CodegenGraph<'a>,
view: &SchemaTypeView<'_, 'a>,
) -> Option<Self>
pub fn for_schema_type( graph: &CodegenGraph<'a>, view: &SchemaTypeView<'_, 'a>, ) -> Option<Self>
Builds a #[cfg(...)] attribute for a schema type, based on
its own resource, and the resources of the operations that use it.
Sourcepub fn for_inline_type(
graph: &CodegenGraph<'a>,
view: &InlineTypeView<'_, 'a>,
) -> Option<Self>
pub fn for_inline_type( graph: &CodegenGraph<'a>, view: &InlineTypeView<'_, 'a>, ) -> Option<Self>
Builds a #[cfg(...)] attribute for an inline type.
Sourcepub fn for_operation(
graph: &CodegenGraph<'a>,
view: &OperationView<'_, 'a>,
) -> Option<Self>
pub fn for_operation( graph: &CodegenGraph<'a>, view: &OperationView<'_, 'a>, ) -> Option<Self>
Builds a #[cfg(...)] attribute for a client method.