IdentMapping

Enum IdentMapping 

pub enum IdentMapping<'a> {
    Type(TypeId),
    Operation(&'a OperationId),
    Path(&'a OperationId, &'a str),
    Query(&'a OperationId, &'a str),
    StructField(TypeId, StructFieldName<'a>),
    EnumVariant(TypeId, &'a str),
    TaggedVariant(TypeId, &'a str),
    UntaggedVariant(TypeId, NonZeroUsize),
    Resource(&'a str),
}
An item with a uniquified Rust identifier in a CodegenGraph.

Variants



Type(TypeId)

A schema or inline type.



Operation(&'a OperationId)

An operation method.



Path(&'a OperationId, &'a str)

A path parameter for an operation.



Query(&'a OperationId, &'a str)

A query parameter for an operation.



StructField(TypeId, StructFieldName<'a>)

A struct field.



EnumVariant(TypeId, &'a str)

A string enum variant.



TaggedVariant(TypeId, &'a str)

A tagged union variant.



UntaggedVariant(TypeId, NonZeroUsize)

An untagged union variant.



Resource(&'a str)

A resource name for a type or an operation.