pub struct CargoManifest(/* private fields */);Expand description
A Cargo.toml manifest.
Implementations
Sourceimpl CargoManifest
impl CargoManifest
Sourcepub fn new(name: &str, version: Version) -> Self
pub fn new(name: &str, version: Version) -> Self
Creates a Cargo manifest with the given package name and version.
Sourcepub fn from_disk(path: &Path) -> Result<Self, CargoManifestError>
pub fn from_disk(path: &Path) -> Result<Self, CargoManifestError>
Reads and parses an existing Cargo manifest from disk.
Sourcepub fn parse(s: &str) -> Result<Self, CargoManifestError>
pub fn parse(s: &str) -> Result<Self, CargoManifestError>
Parses a Cargo manifest from a TOML string.
Sourcepub fn package(&self) -> Option<Package<'_>>
pub fn package(&self) -> Option<Package<'_>>
Returns a view of the package section, or None if this is
a workspace or malformed manifest.
Sourcepub fn apply(self, diff: CargoManifestDiff) -> Self
pub fn apply(self, diff: CargoManifestDiff) -> Self
Applies a diff of changes to the manifest.