pub struct CodegenGraph<'a> { /* private fields */ }Expand description
A CookedGraph decorated with Rust-specific information.
Implementations
Sourceimpl<'a> CodegenGraph<'a>
impl<'a> CodegenGraph<'a>
Sourcepub fn new(cooked: CookedGraph<'a>) -> Self
pub fn new(cooked: CookedGraph<'a>) -> Self
Wraps a type graph with the default configuration.
Sourcepub fn with_config(cooked: CookedGraph<'a>, config: &CodegenConfig) -> Self
pub fn with_config(cooked: CookedGraph<'a>, config: &CodegenConfig) -> Self
Wraps a type graph with the given configuration.
Sourcepub fn ident(&self, key: impl Into<IdentMapping<'a>>) -> UniqueIdent<'a>
pub fn ident(&self, key: impl Into<IdentMapping<'a>>) -> UniqueIdent<'a>
Returns the unique Rust identifier for a schema, operation, parameter, field, or variant.
Sourcepub fn resource_for(&self, view: &impl HasResource<'a>) -> ResourceGroup<'a>
pub fn resource_for(&self, view: &impl HasResource<'a>) -> ResourceGroup<'a>
Returns the resource that contains the given view.
Sourcepub fn date_time_format(&self) -> DateTimeFormat
pub fn date_time_format(&self) -> DateTimeFormat
Returns the format to use for date-time types.
Methods from Deref<Target = CookedGraph<'a>>
Sourcepub fn schemas(
&self,
) -> impl Iterator<Item = SchemaTypeView<'_, 'a>> + use<'_, 'a>
pub fn schemas( &self, ) -> impl Iterator<Item = SchemaTypeView<'_, 'a>> + use<'_, 'a>
Returns an iterator over all the named schemas in this graph.
Sourcepub fn schema(&self, name: &str) -> Option<SchemaTypeView<'_, 'a>>
pub fn schema(&self, name: &str) -> Option<SchemaTypeView<'_, 'a>>
Looks up and returns a schema by name.
Sourcepub fn view(&self, id: TypeId) -> TypeView<'_, 'a>
pub fn view(&self, id: TypeId) -> TypeView<'_, 'a>
Looks up and returns a type view by its identifier.
Sourcepub fn primitives(
&self,
) -> impl Iterator<Item = PrimitiveView<'_, 'a>> + use<'_, 'a>
pub fn primitives( &self, ) -> impl Iterator<Item = PrimitiveView<'_, 'a>> + use<'_, 'a>
Returns an iterator over all primitive type nodes in this graph.
Sourcepub fn operations(
&self,
) -> impl Iterator<Item = OperationView<'_, 'a>> + use<'_, 'a>
pub fn operations( &self, ) -> impl Iterator<Item = OperationView<'_, 'a>> + use<'_, 'a>
Returns an iterator over all the operations in this graph.