pub enum CfgFeature {
Single(CargoFeature),
AnyOf(BTreeSet<CargoFeature>),
AllOf(BTreeSet<CargoFeature>),
OwnAndUsedBy {
own: CargoFeature,
used_by: BTreeSet<CargoFeature>,
},
}Expand description
Generates a #[cfg(...)] attribute for conditional compilation.
Variants
Single(CargoFeature)
A single feature = "name" predicate.
AnyOf(BTreeSet<CargoFeature>)
A compound any(feature = "a", feature = "b", ...) predicate.
AllOf(BTreeSet<CargoFeature>)
A compound all(feature = "a", feature = "b", ...) predicate.
OwnAndUsedBy
A compound all(feature = "own", any(feature = "a", ...)) predicate,
used for schema types that both specify an x-resourceId, and are
used by operations that specify an x-resource-name.
Implementations
Sourceimpl CfgFeature
impl CfgFeature
Sourcepub fn for_schema_type(view: &SchemaIrTypeView<'_>) -> Option<Self>
pub fn for_schema_type(view: &SchemaIrTypeView<'_>) -> Option<Self>
Builds a #[cfg(...)] attribute for a schema type, based on
its own resource, and the resources of the operations that use it.
Sourcepub fn for_inline_type(view: &InlineIrTypeView<'_>) -> Option<Self>
pub fn for_inline_type(view: &InlineIrTypeView<'_>) -> Option<Self>
Builds a #[cfg(...)] attribute for an inline type.
Sourcepub fn for_operation(view: &IrOperationView<'_>) -> Option<Self>
pub fn for_operation(view: &IrOperationView<'_>) -> Option<Self>
Builds a #[cfg(...)] attribute for a client method.
Sourcepub fn for_resource_module(feature: &CargoFeature) -> Option<Self>
pub fn for_resource_module(feature: &CargoFeature) -> Option<Self>
Builds a #[cfg(...)] attribute for a resource mod declaration in a
CodegenClientModule.