pub enum CodegenTypeName<'a> {
Schema(&'a SchemaIrTypeView<'a>),
Inline(&'a InlineIrTypeView<'a>),
}Expand description
A name for a schema or an inline type, used in generated Rust code.
CodegenTypeName is the high-level representation of a type name.
For emitting arbitrary identifiers, like fields, parameters, and methods,
use CodegenIdent and CodegenIdentUsage instead.
CodegenTypeName implements ToTokens to produce PascalCase identifiers
(e.g., Pet, GetItemsFilter) in quote macros.
Use into_module_name for the corresponding module name,
and into_sort_key for deterministic sorting.
Variants
Schema(&'a SchemaIrTypeView<'a>)
Inline(&'a InlineIrTypeView<'a>)
Implementations
Sourceimpl<'a> CodegenTypeName<'a>
impl<'a> CodegenTypeName<'a>
pub fn into_module_name(self) -> CodegenModuleName<'a>
pub fn into_sort_key(self) -> CodegenTypeNameSortKey<'a>